You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by ni...@apache.org on 2010/05/05 18:30:43 UTC

svn commit: r941372 - in /poi/trunk/src: documentation/content/xdocs/status.xml java/org/apache/poi/ss/SpreadsheetVersion.java

Author: nick
Date: Wed May  5 16:30:43 2010
New Revision: 941372

URL: http://svn.apache.org/viewvc?rev=941372&view=rev
Log:
Fix bug #49194 - Correct text size limit for OOXML .xlsx files

Modified:
    poi/trunk/src/documentation/content/xdocs/status.xml
    poi/trunk/src/java/org/apache/poi/ss/SpreadsheetVersion.java

Modified: poi/trunk/src/documentation/content/xdocs/status.xml
URL: http://svn.apache.org/viewvc/poi/trunk/src/documentation/content/xdocs/status.xml?rev=941372&r1=941371&r2=941372&view=diff
==============================================================================
--- poi/trunk/src/documentation/content/xdocs/status.xml (original)
+++ poi/trunk/src/documentation/content/xdocs/status.xml Wed May  5 16:30:43 2010
@@ -34,6 +34,7 @@
 
     <changes>
         <release version="3.7-SNAPSHOT" date="2010-??-??">
+           <action dev="POI-DEVELOPERS" type="fix">49194 - Correct text size limit for OOXML .xlsx files</action>
            <action dev="POI-DEVELOPERS" type="fix">49254 - Fix CellUtils.setFont to use the correct type internally</action>
            <action dev="POI-DEVELOPERS" type="fix">49139 - Properly support 4k big block size in POIFS</action>
            <action dev="POI-DEVELOPERS" type="fix">48936 - Avoid writing malformed CDATA blocks in sharedStrings.xml</action>

Modified: poi/trunk/src/java/org/apache/poi/ss/SpreadsheetVersion.java
URL: http://svn.apache.org/viewvc/poi/trunk/src/java/org/apache/poi/ss/SpreadsheetVersion.java?rev=941372&r1=941371&r2=941372&view=diff
==============================================================================
--- poi/trunk/src/java/org/apache/poi/ss/SpreadsheetVersion.java (original)
+++ poi/trunk/src/java/org/apache/poi/ss/SpreadsheetVersion.java Wed May  5 16:30:43 2010
@@ -36,7 +36,6 @@ public enum SpreadsheetVersion {
 	 * <li>The total number of available rows is 64k (2^16)</li>
 	 * <li>The maximum number of arguments to a function is 30</li>
 	 * <li>Number of conditional format conditions on a cell is 3</li>
-     * <li>Length of text cell contents is unlimited </li>
      * <li>Length of text cell contents is 32767</li>
 	 * </ul>
 	 */
@@ -51,10 +50,10 @@ public enum SpreadsheetVersion {
 	 * <li>The maximum number of arguments to a function is 255</li>
 	 * <li>Number of conditional format conditions on a cell is unlimited
 	 * (actually limited by available memory in Excel)</li>
      * <li>Length of text cell contents is unlimited </li>
 	 * <ul>
 	 */
-	EXCEL2007(0x100000, 0x4000, 255, Integer.MAX_VALUE, Integer.MAX_VALUE);
+	EXCEL2007(0x100000, 0x4000, 255, Integer.MAX_VALUE, 32767);
 
 	private final int _maxRows;
 	private final int _maxColumns;



---------------------------------------------------------------------
@@ -51,10 +50,10 @@ public enum SpreadsheetVersion {
 	 * <li>Number of conditional format conditions on a cell is unlimited
 	 * (actually limited by available memory in Excel)</li>
-     * <li>Length of text cell contents is unlimited </li>
+     * <li>Length of text cell contents is 32767</li>
 	 * <ul>
 	 */
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org